@@ -29,8 +29,6 @@ arg_number = 0
 bot_token = ""
 
 class simple_discord_bot(discord.Client):
-    def __init__(self):
-        pass
     def add_command(self, command_to_add, response, react_to=None, reaction=None, delete=False, connect_to_voicechannel=False, source_to_play=None, DM=False):
 
         command_dict[str(command_to_add)] = {
@@ -45,6 +43,8 @@ class simple_discord_bot(discord.Client):
 
         command_list.append(command_to_add)
 
+    def set_token(self, token):
+        command_dict["discord_bot_token"] = token
 
 @client.event
 async def on_ready():
@@ -221,11 +221,9 @@ async def on_message(message):
                 except Exception as DM_error:
                     print(str(DM_error))
 
-    def set_token(self, token):
-        bot_token = token
 
 try:
     print("Attempting to login to Discord...")
-    client.run(bot_token)
+    client.run(command_dict["discord_bot_token"])
 except Exception as login_error:
     print(login_error)
